(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     60405,       1762]*)
(*NotebookOutlinePosition[     76823,       2190]*)
(*  CellTagsIndexPosition[     75334,       2147]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["M-Debug",
  FontColor->RGBColor[0, 0, 1]]], "Chapter"],

Cell[CellGroupData[{

Cell["Background information", "Section",
  PageWidth->WindowWidth],

Cell[CellGroupData[{

Cell["Introduction to M-Debug", "Subsection",
  CellTags->"SD_Intro"],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " comes with a number of low-level debugging operations, these do not \
operate in a manner analogous to a typical high-level debugger in a \
conventional programming language IDE. With M-Debug the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programmer can debug in a much more intuitive way. M-Debug is designed to \
be used both by experienced ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programmers, and also by complete novices. Most debugger operations are \
initiated from a large palette known as the debugger console. This means \
that, for example, novices can step through their code without needing to \
learn additional syntax. \n\nM-Debug is based on the code for Dbg \[Dash] a \
much simpler debugger that did not use a full GUI interface. \[Dash] It has \
greatly enhanced functionality and a much more intuitive interface.\nAny \
debugging session passes through a number of phases, and great confusion can \
be caused by executing an operation in the wrong phase \[Dash] for example, \
trying to step a program that has not yet been started. To avoid all such \
problems, the M-Debug buttons 'grey' out and become inactive in situations \
where they should not be used.\nThe low-level functions, such as TracePrint, \
are (by default) very verbose. For example, the head 'Sin' in Sin[0.1] is \
shown as being 'evaluated' as a distinct step, and the constant 0.1 is also \
'evaluated'. M-Debug eliminates a variety of uninformative steps of this \
sort.\nM-Debug  is very configurable, but by default it imposes some \
additional syntax checks on user code. These checks eliminate many mistakes \
as code is loaded into the kernel rather than waiting until 'run time'.\nWhen \
 a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program generates a diagnostic, the traditional action is to continue \
execution, suppressing messages of a given type after the first few have been \
printed. By default, M-Debug treats all messages that are not suppressed by \
On or Off as fatal. This forces novices to concentrate on the first \
diagnostic \[Dash] which is usually where the problem lies. It also enables \
users to explore the state of their program at the point where it first \
generated a diagnostic. In a substantial number of cases this action prevents \
programs from entering an indefinite loop.\nAs another aid for novice \
developers, all diagnostics are displayed in a much more prominent fashion in \
a 'dialog box'. This helps users to realise that their program has 'failed' \
and hopefully encourages them to read the diagnostic before clicking the OK \
button!\nBecause M-Debug is heavily configurable, it is important to be able \
to save configuration information for subsequent work. Since most such \
information is entered via the debugger console and a related palettes, it is \
automatically saved for convenience in a file with the same name as the \
notebook, but with a .DBG suffix. This means that M-Debug can be configured \
differently for different projects using different notebooks.\nMany programs \
fail by simply entering an infinite loop. M-Debug has provision for breaking \
into a looping program, exploring its state, and resuming execution or \
abandoning it as appropriate.\nM-Debug employs the concept of coloured code. \
Users can colour portions of their code as a way to control the debugger \
breakpoint processor, and obtain other information. Colouring parts of a \
program is much cleaner than inserting extra temporary code of various sorts \
(e.g. Print) .\nM-Debug makes heavy use of the $FrontEnd, and cannot be used \
in kernel-only environments, although it will operate on code from .M files \
provided this is invoked from a notebook.\nWhen a program is paused by \
M-Debug it is possible to perform side calculations to explore the state of \
the program, or for other purposes. While this can be extremely useful, it \
could also be a source of confusion for the novice, who could easily lose \
track of which code was being debugged. For this reason, the user's main \
notebook is disabled when the debugger is paused in this way \[Dash] any \
extra calculations must be performed in another notebook."
}], "Text"],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  PageWidth->WindowWidth,
  CellTags->"SD_Intro"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting started with the M-Debug", "Section"],

Cell[CellGroupData[{

Cell["Installing the package", "Subsubsection",
  CellTags->"SD_Installing"],

Cell[TextData[{
  "M-Debug is supplied as a ZIP file containing all the files required in \
their appropriate directories.. It is vital that this directory structure is \
preserved. Copy the file to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory, e.g. C:\\program files\\wolfram research\\mathematica\\5.0 \
(the exact directory depends on the version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " installed). Unzip the file M-Debug.ZIP using a tool that preserves the \
directory structure and handles long names correctly, e.g. PKZIP(R)  Version \
2.50, or WinZip(R).\nFinally, start ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", click on the 'Help' menu, and select 'Rebuild Help index'. This will \
integrate the debugger documentation with the rest of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". You will find the Fortlink help in the 'Addons' section of the help \
browser."
}], "Text",
  CellTags->"SD_Installing"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading the package", "Subsubsection",
  CellTags->"SD_Loading"],

Cell["M-Debug should be loaded thus:", "Text",
  CellTags->"SD_Loading"],

Cell[BoxData[
    RowBox[{"<<", "\"\<MDebug`\>\""}]], "Input",
  CellLabel->"In[8]:=",
  CellTags->"SD_Loading"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "Because the debugger interacts with many parts of the Frontend, it is \
recommended that you save your work more frequently while using the \
debugger."
}], "Text"],

Cell["\<\
This will load the debugger and open a small notebook, known as the debugger \
console, which you use to debug code. Typically you should place this command \
at the top of a notebook containing code that you wish to debug (do not place \
it in .M files) because M-Debug will keep your debugger settings in a file \
with the same name as your notebook but with the .DBG suffix.
You should load M-Debug before executing any function definitions, etc. \
associated with code you wish to debug because M-Debug will perform some \
extra syntax checks to ensure your code is valid. 
After loading M-Debug execute all definitions relating to your program but do \
not execute the cell which starts your program running (in very simple cases, \
this may be the only cell). Correct any diagnostics that are produced at this \
stage.
At this point you are ready to run the debugger.\
\>", "Text",
  CellTags->"SD_Loading"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debugging a program", "Subsubsection",
  CellTags->"SD_Debugging"],

Cell["First we load the debugger package if necessary:", "Text",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{"<<", "\"\<MDebug`\>\""}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"SD_Debugging"],

Cell["\<\
Here is a very simple program which is supposed to count down from n \[Dash] \
its argument \[Dash] to zero. It contains some deliberate mistakes!\
\>", "Text",
  CellTags->"SD_Debugging"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"countDown", "[", "k_", "]"}], ":=", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", "}"}], "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
            RowBox[{
              RowBox[{"k", "\[GreaterEqual]", "0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"Print", "[", "k", "]"}], ";", "\[IndentingNewLine]", 
                
                RowBox[{"k", "--"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Debugger", "::", 
        RowBox[{"Syntax", ":", " ", 
          RowBox[{"The", " ", "first", " ", "argument", " ", 
            RowBox[{"to", " ", "'"}], 
            RowBox[{"Module", "'"}]}]}]}], ",", " ", 
      RowBox[{
        RowBox[{"{", "}"}], " ", 
        RowBox[{"(", 
          RowBox[{
          "the", " ", "list", " ", "of", " ", "local", " ", "variables"}], 
          ")"}], " ", "must", " ", "be", " ", "followed", " ", "by", " ", "a",
         " ", 
        RowBox[{"comma", "."}]}]}]], "Message",
  CellTags->"SD_Debugging"],

Cell[BoxData["$Aborted"], "Output",
  CellLabel->"Out[4]=",
  CellTags->"SD_Debugging"]
}, Open  ]],

Cell[TextData[{
  "As you can see, executing this code has caused the debugger to detect a \
syntax error which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would otherwise have ignored until run-time. This error is also reported \
in a much more prominent form as an error dialog box if you actually run this \
example (recommended). Note that by default the debugger treats all error \
messages as fatal, so the above definition was not entered into the kernel \
and the operation aborted. Adding a comma fixes this problem:"
}], "Text",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{"countDown", "[", "k_", "]"}], ":=", 
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
            RowBox[{
              RowBox[{"k", "\[GreaterEqual]", "0"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"Print", "[", "k", "]"}], ";", "\[IndentingNewLine]", 
                
                RowBox[{"k", "--"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "]"}]}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"SD_Debugging"],

Cell["\<\
At this point we can test this code (without debugging it) and again we \
discover a problem:\
\>", "Text",
  CellTags->"SD_Debugging"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"countDown", "[", "5", "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Decrement", "::", "\<\"rvalue\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"\\!\\(5\\) is not a variable with a value, so its \
value cannot be changed. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::rvalue\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData["5"], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"SD_Debugging"]
}, Open  ]],

Cell["\<\
The program went into an infinite loop and had to be aborted. It may be that \
in this simple example the diagnostic has already enabled you to figure out \
what is wrong with the code, however let us discover what M-Debug can do \
here. This time, instead of using \[ShiftKey]\[EnterKey] to execute the cell, \
we click in the cell and press the 'Debug' button on the debugger console:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"countDown", "[", "5", "]"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            1, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["1",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox[
        RowBox[{"countDown", "[", "5", "]"}],
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            2, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["2",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox["Module",
        (Short[ #, 4]&)], 
      TagBox["\<\"[\"\>",
        (Short[ #, 4]&)], 
      TagBox[
        RowBox[{"{", "}"}],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox["\<\" \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["\<\",...\"\>",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            3, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["3",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox["While",
        (Short[ #, 4]&)], 
      TagBox["\<\"[\"\>",
        (Short[ #, 4]&)], 
      TagBox[
        RowBox[{"5", "\[GreaterEqual]", "0"}],
        (Short[ #, 4]&)], 
      TagBox["\<\",...\"\>",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            4, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["4",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox[
        RowBox[{"5", "\[GreaterEqual]", "0"}],
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            5, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["5",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox["True",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            6, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["6",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox[
        RowBox[{"Print", "[", "5", "]"}],
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    InterpretationBox["5",
      SequenceForm[ 5],
      Editable->False]], "Print",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            7, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["7",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox["Null",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            8, "Dbg                     9\n3.2701947448991680 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["8",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox[
        RowBox[{"5", "--"}],
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Decrement", "::", "\<\"rvalue\"\>"}], 
      RowBox[{
      ":", " "}], "\<\"\\!\\(5\\) is not a variable with a value, so its \
value cannot be changed. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::rvalue\\\"]\\)\"\>"}]], "Message",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        TagBox["\<\"Dbg aborting at step \"\>",
          (Short[ #, 4]&)], 
        TagBox["8",
          (Short[ #, 4]&)]}],
      FontColor->RGBColor[1, 0, 0]]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        TagBox["\<\"Inside \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[1, 0, 0]], 
      TagBox["While",
        (Short[ #, 4]&)], 
      TagBox["\<\"[\"\>",
        (Short[ #, 4]&)], 
      TagBox[
        RowBox[{"5", "\[GreaterEqual]", "0"}],
        (Short[ #, 4]&)], 
      TagBox["\<\",...\"\>",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        TagBox["\<\"Inside \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[1, 0, 0]], 
      TagBox["Module",
        (Short[ #, 4]&)], 
      TagBox["\<\"[\"\>",
        (Short[ #, 4]&)], 
      TagBox[
        RowBox[{"{", "}"}],
        (Short[ #, 4]&)], 
      TagBox["\<\",...\"\>",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        TagBox["\<\"While evaluating: \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[1, 0, 0]], 
      TagBox[
        RowBox[{"countDown", "[", "5", "]"}],
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        TagBox["8",
          (Short[ #, 4]&)], 
        TagBox["\<\" steps in all\"\>",
          (Short[ #, 4]&)]}],
      FontColor->RGBColor[1, 0, 0]]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging"]
}, Open  ]],

Cell[BoxData["$Aborted"], "Input",
  CellTags->"SD_Debugging"],

Cell["\<\
Pressing the 'Debug' button created the first of the pink lines above. The \
other lines were created by stepping the program using the 'Step' button. \
Notice how the debugger console changes when you press the buttons. At any \
given point only certain debugger options make sense and the rest are 'greyed \
out' to prevent their use. For example, the 'Step' button is unavailable \
until the 'Debug' button has been used to actually start a session.
In this simple example using the debugger to single-step the program reveals \
all. The goal that was executing when the diagnostic was generated was:\
\>", "Text",
  CellTags->"SD_Debugging"],

Cell[BoxData[
    RowBox[{"5", "--"}]], "Input",
  CellTags->"SD_Debugging"],

Cell["\<\
This is obviously meaningless, but this is a common mistake because the '5' \
began as a pattern variable which looks similar to an ordinary variable. It \
is strongly recommended that you copy the above code to another notebook and \
practice using the debugger on it. Learn how the debugger operates on code \
that you understand, rather than waiting until you have a genuine problem of \
your own!\
\>", "Text",
  CellTags->"SD_Debugging"],

Cell["\<\
Notice that each step contains a small button embedded in it. Although the \
buttons in this notebook will not do anything (because the data that they use \
is stored in the kernel for the lifetime of a debug session, and is long \
gone) if you debug your own copy of the above code you can use these buttons \
to explore the history of a given calculation. \
\>", "Text",
  CellTags->"SD_Debugging"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The debugger console", "Section",
  CellTags->"SD_Console"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"SD_Intro1"],

Cell["\<\
Most debugger operations are controlled from the console that pops up when \
you first load the debugger package. Buttons which cannot be meaningfully \
used at a given point are greyed out and inactive. You will see these buttons \
change as your debug session progresses. Beneath the palette of control \
buttons you will see a status area. This area tells you what the debugger is \
doing, and which step your program is at. If, for example, your program is \
running (say to a breakpoint) you will see the step number increasing in this \
status area. The status area also contains the value of 'N', the number of \
steps to execute when the 'Step N' or Run N' buttons are pressed. You can \
change this value from the debugger option inspector \[Dash] see below.
At the bottom of the debugger console is an area which is used to contain the \
values of watched variables (see below)\
\>", "Text",
  CellTags->"SD_Intro1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Debug button", "Subsection",
  CellTags->"SD_Debug_button"],

Cell["\<\
The 'Debug' button is active when the debugger is first loaded, or after a \
debug session has been completed. To debug a program, first load any \
definitions into the kernel in the usual way, then click into the cell which \
will start your program, and press the 'Debug' button. This will leave the \
program suspended at its first step awaiting further operations. Note that \
once the debug session has started in this way, the notebook containing the \
code under test is frozen to prevent additional calculations being attempted. \
This is designed to reduce the risk of confusion \[Dash] particularly for \
beginners. However, when the debugger is paused it is possible to perform \
side calculations in an other notebook (these will, of course, normally \
access the same kernel).\
\>", "Text",
  CellTags->"SD_Debug_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Step button", "Subsection",
  CellTags->"SD_Step_button"],

Cell["\<\
The 'Step' button is active whenever the debugger is paused part way through \
a calculation. It advances the calculation one step, printing the next step \
into the notebook. For short calculations it is often easiest just to step \
through the entire calculation using this button. In more complicated cases \
you will typically set a breakpoint or use some other means to reach the \
point of interest and then step the code watch what is happening.\
\>", "Text",
  CellTags->"SD_Step_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Resume button", "Subsection",
  CellTags->"SD_Resume_button"],

Cell["\<\
The resume button resumes execution of the program until it completes, or is \
stopped by a breakpoint or the 'Interrupt' button. A program that is resumed \
in this way will execute much less efficiently than it would outside the \
debugger (because the debugger is still doing a great deal of work behind the \
scenes), but the only evidence of its progress (other than any output it \
produces) is the 'Step no' indicator in the debugger console.\
\>", "Text",
  CellTags->"SD_Resume_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Step N button", "Subsection",
  CellTags->"SD_Step_N_button"],

Cell["\<\
This button performs N 'Step' operations (unless the program completes before \
this), where N is a number indicated on the debugger console and adjustable \
using the 'Options' button. This button offers a convenient way of spilling \
out step information quickly.\
\>", "Text",
  CellTags->"SD_Step_N_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Run N button", "Subsection",
  CellTags->"SD_Run_N_button"],

Cell["\<\
This button resumes the program for N steps. It can be used as a quick way to \
get the program into the rough area of interest before switching to the use \
of the 'Step' button.\
\>", "Text",
  CellTags->"SD_Run_N_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Goto step button", "Subsection",
  CellTags->"SD_Goto_step_button"],

Cell["\<\
The 'Goto step' button resumes the program until a particular step number is \
reached. Since all the significant steps in a program are numbered the same \
whether actually displayed or not, this button is mainly useful on a \
subsequent debug session of the same program. For example, suppose that you \
already know that your program fails at step 125031, but you don't understand \
exactly why, it may be useful to re-debug it, go to the step 124950 (say) and \
use 'Step N' to display all the steps from then on leading up to the failure. \
\
\>", "Text",
  CellTags->"SD_Goto_step_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Step over button", "Subsection",
  CellTags->"SD_Step_over_button"],

Cell["\<\
The 'Step over' button silently executes the current calculation and pauses \
when the result is produced. Thus, if you have reached the step g[3] and you \
know that the function g contains many steps but is already tested, pressing \
this button will advance the debugger over this calculation. The program can \
still be interrupted during this process.\
\>", "Text",
  CellTags->"SD_Step_over_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Trace button", "Subsection",
  CellTags->"SD_Trace_button"],

Cell["\<\
Pressing this button while a program is paused inside the debugger will print \
a traceback of how the program got to this point.\
\>", "Text",
  CellTags->"SD_Trace_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Options button", "Subsection",
  CellTags->"SD_Options_button"],

Cell["\<\
The 'Options' button opens the 'Debugger option inspector', which can be used \
to configure the debugger in many ways. The configuration information is \
saved from run to run in a file with the same name as the user's notebook, \
but with a .DBG suffix. \
\>", "Text",
  CellTags->"SD_Options_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Watch button", "Subsection",
  CellTags->"SD_Watch_button"],

Cell["\<\
This button will bring up a prompt for a variable name. Watched variables and \
their values appear at the bottom of the debugger console and are updated as \
the program progresses. This feature uses  the built-in function \
Experimental`ValueFunction, which does not appear (at version 5.0) to work \
for variables starting with a '$'. \
\>", "Text",
  CellTags->"SD_Watch_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Messages button", "Subsection",
  CellTags->"SD_Messages_button"],

Cell["\<\
By default, the debugger treats all unsuppressed error messages (except \
spelling warnings) generated by a program as fatal.This button opens a \
section of the debugger option inspector that contains a list of messages \
that can be produced without triggering any debugger action.\
\>", "Text",
  CellTags->"SD_Messages_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Breakpoints button", "Subsection",
  CellTags->"SD_Breakpoints_button"],

Cell["\<\
This button opens a section of the debugger option inspector that contains a \
list of breakpoint patterns. By changing this list you can insert a \
breakpoint anywhere in your code. For example, if you insert the pattern \
foo[_] in this list, then every 1-argument call of the function 'foo' will \
break to the debugger. After setting breakpoints you typically use the \
'Resume' button to run until the breakpoint is reached.\
\>", "Text",
  CellTags->"SD_Breakpoints_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Colour button", "Subsection",
  CellTags->"SD_Colour_button"],

Cell["\<\
This button is used before a debug session is begun. You select a portion of \
code to colour and press this button. Coloured code behaves specially inside \
the debugger \[Dash] see the section on using colour for more detail.\
\>", "Text",
  CellTags->"SD_Colour_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The No Colour button", "Subsection",
  CellTags->"SD_No_Colour_button"],

Cell["\<\
To remove colour from a program, select a portion of code that was previously \
coloured, and press this button.\
\>", "Text",
  CellTags->"SD_No_Colour_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The two test buttons", "Subsection",
  CellTags->"SD_Test_button"],

Cell["\<\
There are two buttons labelled 'Test1[]' and 'Test2[]'. These buttons attempt \
to evaluate the corresponding function in the Global context. Obviously, it \
is necessary to define suitable functions before using these buttons. For \
example, suppose you had a large matrix A, and you needed to test some \
property of the matrix from within the debugger \[Dash] perhaps to follow the \
convergence (or otherwise) of some algorithm. By writing suitable code for \
one or other of these functions it would be possible to test the matrix at \
any point by pressing the corresponding button.\
\>", "Text",
  CellTags->"SD_Test_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Interrupt button", "Subsection",
  CellTags->"SD_Interrupt_button"],

Cell["\<\
The 'Interrupt' button is only available while the debugger is actually \
running code. Pressing this button interrupts the execution and returns you \
to the debugger. The code can then be stepped, restarted, or abandoned, as \
required. To avoid imposing an excessive speed penalty on code running in the \
debugger, the check for pressing this button is not made on every step. \
Normally this short delay is hardly noticeable, however there could be a \
longer delay if a series of particularly expensive steps were being \
performed.\
\>", "Text",
  CellTags->"SD_Interrupt_button"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Quit debug button", "Subsection",
  CellTags->"SD_Quit_button"],

Cell["\<\
This button quits an unfinished debug session and returns the user notebook \
to a fully interactive state.\
\>", "Text",
  CellTags->"SD_Quit_button"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The debugger option inspector", "Section",
  CellTags->"SD_Option_Inspector"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"SD_Intro2"],

Cell["\<\
The debugger option inspector is opened whenever the 'Options', \
'Breakpoints', or 'Messages' buttons are pressed. The various buttons open \
different sections of this notebook, but once open, you can open other \
sections directly if you wish without returning to the debugger console.
The switches all toggle by clicking on the small square at the left. When \
this square contains a check mark the corresponding feature is enabled. The \
state of all this configuration information is stored in the corresponding \
.DBG file. This file is textual, so it is possible to modify it with an \
editor. To do this it is important to close the corresponding notebook first. \
If you introduce any syntax errors the result will be unpredictable.\
\>", "Text",
  CellTags->"SD_Intro2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Breakpoints section", "Subsection",
  CellTags->"SD_Breakpoints_section"],

Cell["\<\
This section of the debugger options inspector can be accessed by pressing \
the 'Breakpoint' button, or opening the relevant section manually. It \
consists of a list (initially empty) of patterns which will cause the \
debugger to pause when reached. For example, if you would like the debugger \
to pause when a call to myfunc is made, you might amend the list to:\
\>", "Text",
  CellTags->"SD_Breakpoints_section"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"myfunc", "[", "___", "]"}], "}"}]], "Input",
  CellTags->"SD_Breakpoints_section"],

Cell["\<\
In this example the triple underscore pattern will match zero or more \
arguments. You could also use a much more selective pattern if, for example, \
your program contained many different calls to myfunc and you were only \
interested in one case. The list can contain as many patterns as you like. It \
is necessary to press the 'Submit' button to apply the new breakpoint list. \
Take care not to introduce syntax errors into the list.\
\>", "Text",
  CellTags->"SD_Breakpoints_section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Messages section", "Subsection",
  CellTags->"SD_Messages_section"],

Cell["\<\
This section of the debugger options inspector can be accessed by pressing \
the 'Messages' button, or opening the relevant section manually. It consists \
of a list  of messages which will print out without halting the program. \
Initially, this list contains the message General::spell1, since this message \
can often occur for triial reasons. You can alter this list to contain \
whatever messages you wish and then press the 'Submit' button to apply the \
result. Take care not to introduce syntax errors into the list.\
\>", "Text",
  CellTags->"SD_Messages_section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequently adjusted options", "Subsection",
  CellTags->"SD_Frequently_adjusted_options"],

Cell[TextData[{
  StyleBox["Break on coloured expressions",
    FontWeight->"Bold"],
  " \[Dash] When enabled, this causes the debugger to pause whenever a \
coloured expression is encountered."
}], "Text",
  CellTags->"SD_Frequently_adjusted_options"],

Cell[TextData[{
  StyleBox["Conceal package operations",
    FontWeight->"Bold"],
  " \[Dash] Makes the debugger treat operations in packages as atomic to \
avoid cluttering a debug session with irrelevant information. Changing this \
setting will change the step numbering of your code."
}], "Text",
  CellTags->"SD_Frequently_adjusted_options"],

Cell[TextData[{
  StyleBox["Apply extra syntax checks",
    FontWeight->"Bold"],
  " \[Dash] This switch is active even before the debugger is started by \
pressing the 'Debug' button. It enables a number of additional syntax checks \
that help to spot errors before the code starts running. If you pass a \
definition to the kernel that generates one of these diagnostics nothing is \
stored ",
  "\[Dash] you are expected to correct the definition and re-submit it."
}], "Text",
  CellTags->"SD_Frequently_adjusted_options"],

Cell[TextData[{
  StyleBox["Record debug steps (for step information button)",
    FontWeight->"Bold"],
  " \[Dash] By default the debugger records each step of a calculation \
(including steps that are executed silently) so that the structure of the \
calculation can be explored using the '?' buttons on the displayed steps. \
Storing each step can be expensive in time and memory for very large \
calculations, so this button can be turned off to avoid this."
}], "Text",
  CellTags->"SD_Frequently_adjusted_options"],

Cell[TextData[{
  StyleBox["Multi-step count",
    FontWeight->"Bold"],
  " \[Dash] This is the value of 'N' used by the 'Step N' and 'Run N' \
buttons. You can set it to any positive integer, and you must then press the \
'Submit' button for the change to take effect."
}], "Text",
  CellTags->"SD_Frequently_adjusted_options"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Details of extra syntax checks", "Subsection",
  CellTags->"Extra_syntax_checks"],

Cell["\<\
The following checks are applied to any code evaluated while the debugger is \
loaded as well as code explicitly passed to the debugger. They are all \
enabled by default. They can be disabled as a group by using the 'Apply extra \
syntax  checks' switch (above). All these checks are applied as the code is \
passed to the kernel, rather than at run-time (when any diagnostics are \
harder to interpret). In rare cases these checks may invalidate valid code, \
and so may need to be disabled.\
\>", "Text",
  CellTags->"Extra_syntax_checks"],

Cell["\<\
Whenever a diagnostic is generated as a result of these checks, the operation \
is aborted.\
\>", "Text",
  CellTags->"Extra_syntax_checks"],

Cell[TextData[{
  StyleBox["Check argument counts and validity",
    FontWeight->"Bold"],
  " \[Dash] This checks that any function calls to built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operations have the right number of arguments, and that some other \
requirements are met \[Dash] such as the requirement that the first argument \
to Module must be  a list."
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[TextData[{
  StyleBox["Fault implicit nulls",
    FontWeight->"Bold"],
  " \[Dash] This faults expressions involving an extra coma, such as the \
following:"
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ","}], "}"}]], "Input",
  CellLabel->"In[1]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "Null"}], "}"}]], "Output",
  CellLabel->"Out[1]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"foo", "[", 
      RowBox[{"a", ","}], "]"}]], "Input",
  CellLabel->"In[2]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"foo", "[", 
      RowBox[{"a", ",", "Null"}], "]"}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[TextData[{
  "Such expressions are legal ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " input, and have been evaluated above (with 'Fault implicit nulls' turned \
off) to demonstrate what is produced. If the expression contains explicit \
references to Null, no diagnostics are generated, even if it contains \
implicit Null's as well."
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[TextData[{
  StyleBox["Fault non-standard heads",
    FontWeight->"Bold"],
  " \[Dash] This will detect constructs such as the following:"
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"4", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"4", "[", 
      RowBox[{"a", ",", "b"}], "]"}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"foo", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "[", 
      RowBox[{"c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[4]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{
      RowBox[{"foo", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "[", 
      RowBox[{"c", ",", "d"}], "]"}]], "Output",
  CellLabel->"Out[4]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\"\<xxx\>\"", "[", "a", "]"}]], "Input",
  CellLabel->"In[5]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"\<\"xxx\"\>", "[", "a", "]"}]], "Output",
  CellLabel->"Out[5]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "[", 
      RowBox[{"c", ",", "d"}], "]"}]], "Input",
  CellLabel->"In[6]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{
      RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "[", 
      RowBox[{"c", ",", "d"}], "]"}]], "Output",
  CellLabel->"Out[6]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell["\<\
Once again, these constructs are legal code and are occasionally used \
constructively, however beginners (at least) usually only generate them by \
mistake.\
\>", "Text",
  CellTags->"Extra_syntax_checks"],

Cell[TextData[{
  StyleBox["Fault suspicious implicit multiplications",
    FontWeight->"Bold"],
  " \[Dash] When a semicolon is accidentally omitted, the result is a \
spurious multiplication. Obviously, this cannot always be detected, but where \
this results in a multiplication on the LHS of an assignment, it is obviously \
wrong. For example:"
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"Module", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"a", "=", 
            RowBox[{
              RowBox[{"3", "\[IndentingNewLine]", "b"}], "=", "4"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
  CellLabel->"In[12]:=",
  CellTags->"Extra_syntax_checks"],

Cell[TextData[{
  StyleBox["Fault use of slot notation (#) outside of pure functions",
    FontWeight->"Bold"],
  " \[Dash] This will fault code such as the following, even though it will \
'evaluate' as shown:"
}], "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Map", "[", 
      RowBox[{
        RowBox[{"#", "+", "1"}], ",", 
        RowBox[{"{", 
          RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input",
  CellLabel->"In[7]:=",
  CellTags->"Extra_syntax_checks"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", "#1"}], ")"}], "[", "a", "]"}], ",", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", "#1"}], ")"}], "[", "b", "]"}], ",", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"1", "+", "#1"}], ")"}], "[", "c", "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[7]=",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell["\<\
The diagnostic invites the user to add the missing '&' character!\
\>", "Text",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous debugger configuration", "Subsection",
  CellTags->"SD_Miscellaneous_debugger_configuration"],

Cell[TextData[{
  StyleBox["Debugger console floating",
    FontWeight->"Bold"],
  " \[Dash] This switch is on by default, and causes the debugger console to \
float over other notebooks and windows except while the program is actually \
running (e.g. because 'Resume' or 'Step over' has been pressed)."
}], "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],

Cell[TextData[{
  StyleBox["Use TraceInternal for debug ",
    FontWeight->"Bold"],
  "\[Dash] This corresponds to the option for the Trace functions of the same \
name. It is off by default, and when set, it causes the debugger to show some \
internal steps of certain built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions."
}], "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],

Cell[TextData[{
  StyleBox["Use multiple information notebooks ",
    FontWeight->"Bold"],
  "\[Dash] Normally, if you generate an information notebook by pressing the \
'?' button the debugger will re-use any existing information notebook. \
Setting this switch will cause the debugger to use a separate notebook each \
time."
}], "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],

Cell[TextData[{
  StyleBox["Use message boxes",
    FontWeight->"Bold"],
  " \[Dash] This switch is on by default, and causes the debugger to report \
diagnostics in prominent yellow boxes as well as placing them in the notebook \
in the usual way. Turning this switch off will remove this feature."
}], "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],

Cell[TextData[{
  StyleBox["Re-seed random number generator",
    FontWeight->"Bold"],
  " \[Dash] Normally ",
  "M-Debug",
  " re-seeds the random number generator each time the 'Debug' button is \
pressed. This means that each run of the debugger produces the same results. \
Turn this switch off to get different random numbers from run to run."
}], "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debugging using colour", "Section",
  CellTags->"SD_Debugging_using_colour"],

Cell["\<\
Often the easiest way to debug a program is to use colour. To use the \
'Colour' button you first need to highlight a variable or expression in your \
code. It is important to highlight a syntactically complete piece of code, \
and the easiest way to do this is to repeatedly click inside an expression \
progressively highlighting larger and larger expressions. Once the correct \
expression has been highlighted, the 'Colour' button will apply a permanent \
colour to the expression.
Coloured expressions can appear both in expressions that are going to be \
directly debugged, and also in other definitions. In the latter case, the \
definition should be re-evaluated after adding colour. In the following \
example we colour a sub-expression and enter the debugger. After this, we \
press 'Resume' to execute the code without printing out the individual steps.\
\
\>", "Text",
  CellTags->"SD_Debugging_using_colour"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Module", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
              RowBox[{"x", "=", "0"}], ",", 
              RowBox[{"k", "=", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"While", "[", 
              RowBox[{
                RowBox[{"k", "<", "5"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{"x", "=", 
                    RowBox[{"x", "+", 
                      TagBox[
                        StyleBox[
                          RowBox[{"k", "^", "2"}],
                          Background->RGBColor[1, 1, 0]],
                        Identity]}]}], ";", "\[IndentingNewLine]", 
                  RowBox[{"k", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
            ";", "\[IndentingNewLine]", "x"}]}], "\[IndentingNewLine]", "]"}],
       "\[IndentingNewLine]"}]], "Input",
  CellLabel->"In[3]:=",
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        ButtonBox[
          StyleBox["?",
            FontWeight->"Bold"],
          
          ButtonFunction:>MDebug`Private`Evaluation\[Breve]Info[ 
            1, "Dbg                     9\n3.2709935708120960 10"],
          ButtonEvaluator->Automatic,
          Active->True], 
        StyleBox[
          RowBox[{
            TagBox["\<\"(\"\>",
              (Short[ #, 4]&)], 
            TagBox["1",
              (Short[ #, 4]&)], 
            TagBox["\<\")     \"\>",
              (Short[ #, 4]&)]}],
          FontColor->RGBColor[1, 0, 0]]}], 
      TagBox["Module",
        (Short[ #, 4]&)], 
      TagBox["\<\"[\"\>",
        (Short[ #, 4]&)], 
      TagBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{"x", "=", "0"}], ",", 
            RowBox[{"k", "=", "1"}]}], "}"}],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox[
          RowBox[{"{", 
            RowBox[{"\<\"x$232\"\>", ",", "\<\"k$232\"\>"}], "}"}],
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["\<\",...\"\>",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    RowBox[{
      TagBox[
        TagBox[
          StyleBox[
            SuperscriptBox["k$232", "2"],
            Background->RGBColor[1, 1, 0]],
          Identity],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox["\<\"  \[LongRightArrow]  \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["1",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    RowBox[{
      TagBox[
        TagBox[
          StyleBox[
            SuperscriptBox["k$232", "2"],
            Background->RGBColor[1, 1, 0]],
          Identity],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox["\<\"  \[LongRightArrow]  \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["4",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    RowBox[{
      TagBox[
        TagBox[
          StyleBox[
            SuperscriptBox["k$232", "2"],
            Background->RGBColor[1, 1, 0]],
          Identity],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox["\<\"  \[LongRightArrow]  \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["9",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    RowBox[{
      TagBox[
        TagBox[
          StyleBox[
            SuperscriptBox["k$232", "2"],
            Background->RGBColor[1, 1, 0]],
          Identity],
        (Short[ #, 4]&)], 
      StyleBox[
        TagBox["\<\"  \[LongRightArrow]  \"\>",
          (Short[ #, 4]&)],
        FontColor->RGBColor[0, 0, 1]], 
      TagBox["16",
        (Short[ #, 4]&)]}]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        TagBox["191",
          (Short[ #, 4]&)], 
        TagBox["\<\" steps in all\"\>",
          (Short[ #, 4]&)]}],
      FontColor->RGBColor[1, 0, 0]]], "Print",
  Background->RGBColor[1, 0.8, 0.8],
  CellTags->"SD_Debugging_using_colour"],

Cell[BoxData["30"], "Output",
  CellTags->"SD_Debugging_using_colour"]
}, Open  ]],

Cell["\<\
As shown, the coloured expressions evaluate normally, but generate debug \
information when they are evaluated. It is also possible to pause the \
debugger each time a coloured expression is encountered by setting the 'Break \
on coloured expressions' switch.

It is important not to colour expressions that will not be evaluated \[Dash] \
say because they are an argument of Hold. Doing so will change the structure \
of the expression and change the behavior of the program.\
\>", "Text",
  CellTags->"SD_Debugging_using_colour"],

Cell["\<\
To remove colour from the notebook copy of an expression, select the coloured \
expression and press the 'No colour' button.\
\>", "Text",
  CellTags->"SD_Debugging_using_colour"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Context dependant information", "Section",
  CellTags->"SD_ContextDependantHelp"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"SD_Intro3"],

Cell["\<\
The following sections explain the three states that the debugger passes \
through as you use it to debug your code.\
\>", "Text",
  CellTags->"SD_Intro3"],

Cell[CellGroupData[{

Cell["Standby state", "Subsubsection",
  CellTags->"SD_StandbyState"],

Cell["\<\
At this point you can see the debugger control panel. Note that only some of \
the buttons on this panel are active. This is designed to prevent you \
pressing a button that is inappropriate in a particular situation. Thus, for \
example, the \"Trace\" button is inactive at this point because the debugger \
has not yet been activated. Note that activating/deactivating of these \
buttons does take a small fraction of a second and you should avoid repeated \
clicking on a button at high speed otherwise you may 'beat' this mechanism \
and confuse the debugger.\
\>", "Text",
  CellTags->"SD_StandbyState"],

Cell[TextData[{
  "In this state the debugger is loaded and ready for use. You should submit \
all relevant definitions to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the usual way and click into the cell which starts your calculation. \
Now press the \"Debug\" button (instead of pressing \[ShiftKey]\[EnterKey] as \
you normally would at this point) to start the interactive debugger.\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pausing state", "Subsubsection",
  CellTags->"SD_PausingState"],

Cell["\<\
In the pausing state the debugger is awaiting the next command to debug the \
program. To avoid confusion, the debugger normally prevents you making \
changes in the notebook containing the calculation being debugged.\
\>", "Text",
  CellTags->"SD_PausingState"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Running state", "Subsubsection",
  CellTags->"SD_RunningState"],

Cell["\<\
In the running state your program is being executed under control of the \
debugger. The running state is often entered very briefly \[Dash] say when \
you step your program. If the running state persists for an appreciable time \
(say because you pressed \"Resume\") you will see the step number advancing \
on the control panel. If necessary, you can also press \"Interrupt\" to pause \
the program again.\
\>", "Text",
  CellTags->"SD_RunningState"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Limitations associated with TraceScan", "Section",
  CellTags->"SD_TraceScan_limitations"],

Cell[TextData[{
  "M-Debug is based on the 4-argument form of the TraceScan built-in \
function, and as such, it inherits certain bugs/features associated with \
TraceScan and the Trace functions generally. Hopefully future versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will address these issues."
}], "Text",
  CellTags->"SD_TraceScan_limitations"],

Cell["\<\
\[FilledSmallCircle] None of the Trace functions, including TraceScan, trace \
into calls to a function being plotted by Plot and related functions. It is \
not clear if this is a bug or a 'feature' designed to hide the sampling \
process. M-Debug obviously inherits this unfortunate restriction.
\[FilledSmallCircle] In rare cases, the 4-argument form of TraceScan can \
change the semantics of a program. This only happens when a program being \
debugged re-defines a function on the fly. Usually this is done using \
SetDelayed (:=) and M-Debug corrects these cases. Functions that are \
re-defined on the fly using Set (=) can, however cause problems.\
\>", "Text",
  CellTags->"SD_TraceScan_limitations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["For the curious", "Section",
  CellTags->"SD_For_the_curious"],

Cell[TextData[{
  "M-Debug is a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " application like any other. Almost all the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functionality that it uses is documented. At the heart of the debugger is \
the TraceScan function, which was partly broken for several versions \[Dash] \
hence the need for version 5.0 or above.\nThe variable watch facility uses \
the Experimental`ValueFunction to do its work. Hopefully this function will \
become part of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " proper at a subsequent version, and M-Debug will be updated as necessary.\
\nThe toggle switches are implemented by re-writing the code for the switch \
each time it is pressed. The same technique is used to 'grey' the various \
buttons on the debugger console.\nThe 'Interrupt' button was hard to \
implement because pressing a button to evaluate kernel code while other code \
is already executing normally queues the request! Currently the interrupt \
button sets an irrelevant notebook option on the debugger console notebook, \
and the debugger checks the value of this option at intervals. Checking this \
option requires a trip to the $FrontEnd, and so is too expensive to do on \
every step.\nAlthough this is not documented, the Trace functions (including \
TraceScan) do not normally work if invoked from a button! The 'Debug' button \
uses some undocumented tricks (which occasionally fail) to bypass this \
restriction.\nThe extra syntax restrictions are imposed using the $Pre and \
$PreRead facilities to analyse definitions before they are submitted to the \
kernel or the debugger. Programs that manipulate these variables may not work \
correctly under the debugger.\nThe step number display in the debugger \
console obviously has to update very efficiently. The display is implemented \
using a CounterBox as this was found to give a much less glitchy appearance \
compared with rewriting the cell. Also, as explained above, it is not updated \
at every step.\n"
}], "Text",
  CellTags->"SD_For_the_curious"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
Selectable->True,
WindowSize->{1107, 929},
WindowMargins->{{42, Automatic}, {Automatic, -26}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {"\[Copyright]1998 Salford Software Ltd."}], "PageFooter"], 
      Inherited}, {Inherited, Cell[ 
        TextData[ {"\[Copyright]1998 Salford Software Ltd."}], "PageFooter"], 
      Inherited}},
PrivateNotebookOptions->{"ShortBoxForm"->False},
ShowCellBracket->True,
ShowCellLabel->False,
ShowCellTags->True,
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SD_Intro"->{
    Cell[1971, 63, 69, 1, 77, "Subsection",
      CellTags->"SD_Intro"],
    Cell[6360, 133, 109, 3, 70, "Text",
      CellTags->"SD_Intro"]},
  "SD_Installing"->{
    Cell[6594, 146, 76, 1, 70, "Subsubsection",
      CellTags->"SD_Installing"],
    Cell[6673, 149, 993, 22, 70, "Text",
      CellTags->"SD_Installing"]},
  "SD_Loading"->{
    Cell[7703, 176, 70, 1, 70, "Subsubsection",
      CellTags->"SD_Loading"],
    Cell[7776, 179, 72, 1, 70, "Text",
      CellTags->"SD_Loading"],
    Cell[7851, 182, 112, 3, 70, "Input",
      CellTags->"SD_Loading"],
    Cell[8232, 196, 923, 15, 70, "Text",
      CellTags->"SD_Loading"]},
  "SD_Debugging"->{
    Cell[9192, 216, 72, 1, 70, "Subsubsection",
      CellTags->"SD_Debugging"],
    Cell[9267, 219, 92, 1, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[9362, 222, 114, 3, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[9479, 227, 198, 4, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[9702, 235, 630, 16, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[10335, 253, 587, 15, 70, "Message",
      CellTags->"SD_Debugging"],
    Cell[10925, 270, 87, 2, 70, "Output",
      CellTags->"SD_Debugging"],
    Cell[11027, 275, 581, 11, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[11611, 288, 635, 16, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[12249, 306, 145, 4, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[12419, 314, 117, 3, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[12539, 319, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[12626, 323, 418, 9, 70, "Message",
      CellTags->"SD_Debugging"],
    Cell[13047, 334, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[13134, 338, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[13221, 342, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[13308, 346, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[13395, 350, 84, 2, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[13929, 365, 117, 3, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[14049, 370, 763, 24, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[14815, 396, 1016, 34, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[15834, 432, 922, 30, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[16759, 464, 764, 24, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[17526, 490, 724, 23, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[18253, 515, 759, 24, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[19015, 541, 126, 4, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[19144, 547, 724, 23, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[19871, 572, 746, 24, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[20620, 598, 389, 8, 70, "Message",
      CellTags->"SD_Debugging"],
    Cell[21012, 608, 281, 9, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[21296, 619, 466, 16, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[21765, 637, 448, 16, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[22216, 655, 318, 10, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[22537, 667, 273, 9, 70, "Print",
      CellTags->"SD_Debugging"],
    Cell[22825, 679, 62, 1, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[22890, 682, 655, 10, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[23548, 694, 76, 2, 70, "Input",
      CellTags->"SD_Debugging"],
    Cell[23627, 698, 452, 8, 70, "Text",
      CellTags->"SD_Debugging"],
    Cell[24082, 708, 410, 7, 70, "Text",
      CellTags->"SD_Debugging"]},
  "SD_Console"->{
    Cell[24541, 721, 65, 1, 70, "Section",
      CellTags->"SD_Console"]},
  "SD_Intro1"->{
    Cell[24631, 726, 59, 1, 70, "Subsection",
      CellTags->"SD_Intro1"],
    Cell[24693, 729, 936, 14, 70, "Text",
      CellTags->"SD_Intro1"]},
  "SD_Debug_button"->{
    Cell[25666, 748, 69, 1, 70, "Subsection",
      CellTags->"SD_Debug_button"],
    Cell[25738, 751, 844, 13, 70, "Text",
      CellTags->"SD_Debug_button"]},
  "SD_Step_button"->{
    Cell[26619, 769, 67, 1, 70, "Subsection",
      CellTags->"SD_Step_button"],
    Cell[26689, 772, 506, 8, 70, "Text",
      CellTags->"SD_Step_button"]},
  "SD_Resume_button"->{
    Cell[27232, 785, 71, 1, 70, "Subsection",
      CellTags->"SD_Resume_button"],
    Cell[27306, 788, 505, 8, 70, "Text",
      CellTags->"SD_Resume_button"]},
  "SD_Step_N_button"->{
    Cell[27848, 801, 71, 1, 70, "Subsection",
      CellTags->"SD_Step_N_button"],
    Cell[27922, 804, 321, 6, 70, "Text",
      CellTags->"SD_Step_N_button"]},
  "SD_Run_N_button"->{
    Cell[28280, 815, 69, 1, 70, "Subsection",
      CellTags->"SD_Run_N_button"],
    Cell[28352, 818, 234, 5, 70, "Text",
      CellTags->"SD_Run_N_button"]},
  "SD_Goto_step_button"->{
    Cell[28623, 828, 77, 1, 70, "Subsection",
      CellTags->"SD_Goto_step_button"],
    Cell[28703, 831, 605, 10, 70, "Text",
      CellTags->"SD_Goto_step_button"]},
  "SD_Step_over_button"->{
    Cell[29345, 846, 77, 1, 70, "Subsection",
      CellTags->"SD_Step_over_button"],
    Cell[29425, 849, 415, 7, 70, "Text",
      CellTags->"SD_Step_over_button"]},
  "SD_Trace_button"->{
    Cell[29877, 861, 69, 1, 70, "Subsection",
      CellTags->"SD_Trace_button"],
    Cell[29949, 864, 184, 4, 70, "Text",
      CellTags->"SD_Trace_button"]},
  "SD_Options_button"->{
    Cell[30170, 873, 73, 1, 70, "Subsection",
      CellTags->"SD_Options_button"],
    Cell[30246, 876, 313, 6, 70, "Text",
      CellTags->"SD_Options_button"]},
  "SD_Watch_button"->{
    Cell[30596, 887, 69, 1, 70, "Subsection",
      CellTags->"SD_Watch_button"],
    Cell[30668, 890, 393, 7, 70, "Text",
      CellTags->"SD_Watch_button"]},
  "SD_Messages_button"->{
    Cell[31098, 902, 75, 1, 70, "Subsection",
      CellTags->"SD_Messages_button"],
    Cell[31176, 905, 341, 6, 70, "Text",
      CellTags->"SD_Messages_button"]},
  "SD_Breakpoints_button"->{
    Cell[31554, 916, 81, 1, 70, "Subsection",
      CellTags->"SD_Breakpoints_button"],
    Cell[31638, 919, 490, 8, 70, "Text",
      CellTags->"SD_Breakpoints_button"]},
  "SD_Colour_button"->{
    Cell[32165, 932, 71, 1, 70, "Subsection",
      CellTags->"SD_Colour_button"],
    Cell[32239, 935, 283, 5, 70, "Text",
      CellTags->"SD_Colour_button"]},
  "SD_No_Colour_button"->{
    Cell[32559, 945, 77, 1, 70, "Subsection",
      CellTags->"SD_No_Colour_button"],
    Cell[32639, 948, 171, 4, 70, "Text",
      CellTags->"SD_No_Colour_button"]},
  "SD_Test_button"->{
    Cell[32847, 957, 72, 1, 70, "Subsection",
      CellTags->"SD_Test_button"],
    Cell[32922, 960, 642, 10, 70, "Text",
      CellTags->"SD_Test_button"]},
  "SD_Interrupt_button"->{
    Cell[33601, 975, 77, 1, 70, "Subsection",
      CellTags->"SD_Interrupt_button"],
    Cell[33681, 978, 597, 10, 70, "Text",
      CellTags->"SD_Interrupt_button"]},
  "SD_Quit_button"->{
    Cell[34315, 993, 73, 1, 70, "Subsection",
      CellTags->"SD_Quit_button"],
    Cell[34391, 996, 161, 4, 70, "Text",
      CellTags->"SD_Quit_button"]},
  "SD_Option_Inspector"->{
    Cell[34601, 1006, 83, 1, 70, "Section",
      CellTags->"SD_Option_Inspector"]},
  "SD_Intro2"->{
    Cell[34709, 1011, 59, 1, 70, "Subsection",
      CellTags->"SD_Intro2"],
    Cell[34771, 1014, 791, 12, 70, "Text",
      CellTags->"SD_Intro2"]},
  "SD_Breakpoints_section"->{
    Cell[35599, 1031, 83, 1, 70, "Subsection",
      CellTags->"SD_Breakpoints_section"],
    Cell[35685, 1034, 429, 7, 70, "Text",
      CellTags->"SD_Breakpoints_section"],
    Cell[36117, 1043, 129, 3, 70, "Input",
      CellTags->"SD_Breakpoints_section"],
    Cell[36249, 1048, 500, 8, 70, "Text",
      CellTags->"SD_Breakpoints_section"]},
  "SD_Messages_section"->{
    Cell[36786, 1061, 77, 1, 70, "Subsection",
      CellTags->"SD_Messages_section"],
    Cell[36866, 1064, 583, 9, 70, "Text",
      CellTags->"SD_Messages_section"]},
  "SD_Frequently_adjusted_options"->{
    Cell[37486, 1078, 95, 1, 70, "Subsection",
      CellTags->"SD_Frequently_adjusted_options"],
    Cell[37584, 1081, 252, 6, 70, "Text",
      CellTags->"SD_Frequently_adjusted_options"],
    Cell[37839, 1089, 346, 7, 70, "Text",
      CellTags->"SD_Frequently_adjusted_options"],
    Cell[38188, 1098, 526, 10, 70, "Text",
      CellTags->"SD_Frequently_adjusted_options"],
    Cell[38717, 1110, 520, 9, 70, "Text",
      CellTags->"SD_Frequently_adjusted_options"],
    Cell[39240, 1121, 328, 7, 70, "Text",
      CellTags->"SD_Frequently_adjusted_options"]},
  "Extra_syntax_checks"->{
    Cell[39605, 1133, 87, 1, 70, "Subsection",
      CellTags->"Extra_syntax_checks"],
    Cell[39695, 1136, 552, 9, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[40250, 1147, 150, 4, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[40403, 1153, 431, 10, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[40837, 1165, 209, 6, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[41071, 1175, 153, 4, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[41227, 1181, 162, 4, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[41426, 1190, 140, 4, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[41569, 1196, 149, 4, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[41733, 1203, 400, 9, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[42136, 1214, 190, 5, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[42351, 1223, 143, 4, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[42497, 1229, 144, 4, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[42678, 1238, 206, 6, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[42887, 1246, 207, 6, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[43131, 1257, 126, 3, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[43260, 1262, 127, 3, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[43424, 1270, 199, 6, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[43626, 1278, 200, 6, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[43841, 1287, 216, 5, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[44060, 1294, 396, 8, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[44459, 1304, 407, 11, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[44869, 1317, 258, 6, 70, "Text",
      CellTags->"Extra_syntax_checks"],
    Cell[45152, 1327, 244, 7, 70, "Input",
      CellTags->"Extra_syntax_checks"],
    Cell[45399, 1336, 453, 14, 70, "Output",
      CellTags->"Extra_syntax_checks"],
    Cell[45867, 1353, 124, 3, 70, "Text",
      CellTags->"Extra_syntax_checks"]},
  "SD_Miscellaneous_debugger_configuration"->{
    Cell[46028, 1361, 113, 1, 70, "Subsection",
      CellTags->"SD_Miscellaneous_debugger_configuration"],
    Cell[46144, 1364, 370, 7, 70, "Text",
      CellTags->"SD_Miscellaneous_debugger_configuration"],
    Cell[46517, 1373, 416, 10, 70, "Text",
      CellTags->"SD_Miscellaneous_debugger_configuration"],
    Cell[46936, 1385, 394, 8, 70, "Text",
      CellTags->"SD_Miscellaneous_debugger_configuration"],
    Cell[47333, 1395, 366, 7, 70, "Text",
      CellTags->"SD_Miscellaneous_debugger_configuration"],
    Cell[47702, 1404, 415, 9, 70, "Text",
      CellTags->"SD_Miscellaneous_debugger_configuration"]},
  "SD_Debugging_using_colour"->{
    Cell[48166, 1419, 82, 1, 70, "Section",
      CellTags->"SD_Debugging_using_colour"],
    Cell[48251, 1422, 931, 15, 70, "Text",
      CellTags->"SD_Debugging_using_colour"],
    Cell[49207, 1441, 994, 24, 70, "Input",
      CellTags->"SD_Debugging_using_colour"],
    Cell[50204, 1467, 1211, 39, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[51418, 1508, 476, 16, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[51897, 1526, 476, 16, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[52376, 1544, 476, 16, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[52855, 1562, 477, 16, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[53335, 1580, 288, 9, 70, "Print",
      CellTags->"SD_Debugging_using_colour"],
    Cell[53626, 1591, 70, 1, 70, "Output",
      CellTags->"SD_Debugging_using_colour"],
    Cell[53711, 1595, 541, 10, 70, "Text",
      CellTags->"SD_Debugging_using_colour"],
    Cell[54255, 1607, 189, 4, 70, "Text",
      CellTags->"SD_Debugging_using_colour"]},
  "SD_ContextDependantHelp"->{
    Cell[54481, 1616, 87, 1, 70, "Section",
      CellTags->"SD_ContextDependantHelp"]},
  "SD_Intro3"->{
    Cell[54593, 1621, 59, 1, 70, "Subsection",
      CellTags->"SD_Intro3"],
    Cell[54655, 1624, 165, 4, 70, "Text",
      CellTags->"SD_Intro3"]},
  "SD_StandbyState"->{
    Cell[54845, 1632, 69, 1, 70, "Subsubsection",
      CellTags->"SD_StandbyState"],
    Cell[54917, 1635, 618, 10, 70, "Text",
      CellTags->"SD_StandbyState"]},
  "SD_PausingState"->{
    Cell[55994, 1660, 69, 1, 70, "Subsubsection",
      CellTags->"SD_PausingState"],
    Cell[56066, 1663, 272, 5, 70, "Text",
      CellTags->"SD_PausingState"]},
  "SD_RunningState"->{
    Cell[56375, 1673, 69, 1, 70, "Subsubsection",
      CellTags->"SD_RunningState"],
    Cell[56447, 1676, 462, 8, 70, "Text",
      CellTags->"SD_RunningState"]},
  "SD_TraceScan_limitations"->{
    Cell[56970, 1691, 96, 1, 70, "Section",
      CellTags->"SD_TraceScan_limitations"],
    Cell[57069, 1694, 374, 8, 70, "Text",
      CellTags->"SD_TraceScan_limitations"],
    Cell[57446, 1704, 719, 11, 70, "Text",
      CellTags->"SD_TraceScan_limitations"]},
  "SD_For_the_curious"->{
    Cell[58202, 1720, 68, 1, 70, "Section",
      CellTags->"SD_For_the_curious"],
    Cell[58273, 1723, 2104, 35, 70, "Text",
      CellTags->"SD_For_the_curious"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SD_Intro", 61500, 1791},
  {"SD_Installing", 61664, 1796},
  {"SD_Loading", 61840, 1801},
  {"SD_Debugging", 62154, 1810},
  {"SD_Console", 65107, 1889},
  {"SD_Intro1", 65199, 1892},
  {"SD_Debug_button", 65371, 1897},
  {"SD_Step_button", 65554, 1902},
  {"SD_Resume_button", 65736, 1907},
  {"SD_Step_N_button", 65922, 1912},
  {"SD_Run_N_button", 66107, 1917},
  {"SD_Goto_step_button", 66294, 1922},
  {"SD_Step_over_button", 66490, 1927},
  {"SD_Trace_button", 66681, 1932},
  {"SD_Options_button", 66866, 1937},
  {"SD_Watch_button", 67053, 1942},
  {"SD_Messages_button", 67239, 1947},
  {"SD_Breakpoints_button", 67434, 1952},
  {"SD_Colour_button", 67630, 1957},
  {"SD_No_Colour_button", 67819, 1962},
  {"SD_Test_button", 68009, 1967},
  {"SD_Interrupt_button", 68195, 1972},
  {"SD_Quit_button", 68386, 1977},
  {"SD_Option_Inspector", 68571, 1982},
  {"SD_Intro2", 68673, 1985},
  {"SD_Breakpoints_section", 68854, 1990},
  {"SD_Messages_section", 69228, 1999},
  {"SD_Frequently_adjusted_options", 69436, 2004},
  {"Extra_syntax_checks", 70028, 2017},
  {"SD_Miscellaneous_debugger_configuration", 72238, 2070},
  {"SD_Debugging_using_colour", 72891, 2083},
  {"SD_ContextDependantHelp", 73998, 2108},
  {"SD_Intro3", 74104, 2111},
  {"SD_StandbyState", 74277, 2116},
  {"SD_PausingState", 74466, 2121},
  {"SD_RunningState", 74654, 2126},
  {"SD_TraceScan_limitations", 74851, 2131},
  {"SD_For_the_curious", 75142, 2138}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 78, 1, 130, "Chapter"],

Cell[CellGroupData[{
Cell[1879, 58, 67, 1, 82, "Section"],

Cell[CellGroupData[{
Cell[1971, 63, 69, 1, 77, "Subsection",
  CellTags->"SD_Intro"],
Cell[2043, 66, 4314, 65, 922, "Text"],
Cell[6360, 133, 109, 3, 70, "Text",
  CellTags->"SD_Intro"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6518, 142, 51, 0, 70, "Section"],

Cell[CellGroupData[{
Cell[6594, 146, 76, 1, 70, "Subsubsection",
  CellTags->"SD_Installing"],
Cell[6673, 149, 993, 22, 70, "Text",
  CellTags->"SD_Installing"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7703, 176, 70, 1, 70, "Subsubsection",
  CellTags->"SD_Loading"],
Cell[7776, 179, 72, 1, 70, "Text",
  CellTags->"SD_Loading"],
Cell[7851, 182, 112, 3, 70, "Input",
  CellTags->"SD_Loading"],
Cell[7966, 187, 263, 7, 70, "Text"],
Cell[8232, 196, 923, 15, 70, "Text",
  CellTags->"SD_Loading"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9192, 216, 72, 1, 70, "Subsubsection",
  CellTags->"SD_Debugging"],
Cell[9267, 219, 92, 1, 70, "Text",
  CellTags->"SD_Debugging"],
Cell[9362, 222, 114, 3, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[9479, 227, 198, 4, 70, "Text",
  CellTags->"SD_Debugging"],

Cell[CellGroupData[{
Cell[9702, 235, 630, 16, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[10335, 253, 587, 15, 70, "Message",
  CellTags->"SD_Debugging"],
Cell[10925, 270, 87, 2, 70, "Output",
  CellTags->"SD_Debugging"]
}, Open  ]],
Cell[11027, 275, 581, 11, 70, "Text",
  CellTags->"SD_Debugging"],
Cell[11611, 288, 635, 16, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[12249, 306, 145, 4, 70, "Text",
  CellTags->"SD_Debugging"],

Cell[CellGroupData[{
Cell[12419, 314, 117, 3, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[12539, 319, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[12626, 323, 418, 9, 70, "Message",
  CellTags->"SD_Debugging"],
Cell[13047, 334, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[13134, 338, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[13221, 342, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[13308, 346, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[13395, 350, 84, 2, 70, "Print",
  CellTags->"SD_Debugging"]
}, Open  ]],
Cell[13494, 355, 410, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[13929, 365, 117, 3, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[14049, 370, 763, 24, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[14815, 396, 1016, 34, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[15834, 432, 922, 30, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[16759, 464, 764, 24, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[17526, 490, 724, 23, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[18253, 515, 759, 24, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[19015, 541, 126, 4, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[19144, 547, 724, 23, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[19871, 572, 746, 24, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[20620, 598, 389, 8, 70, "Message",
  CellTags->"SD_Debugging"],
Cell[21012, 608, 281, 9, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[21296, 619, 466, 16, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[21765, 637, 448, 16, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[22216, 655, 318, 10, 70, "Print",
  CellTags->"SD_Debugging"],
Cell[22537, 667, 273, 9, 70, "Print",
  CellTags->"SD_Debugging"]
}, Open  ]],
Cell[22825, 679, 62, 1, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[22890, 682, 655, 10, 70, "Text",
  CellTags->"SD_Debugging"],
Cell[23548, 694, 76, 2, 70, "Input",
  CellTags->"SD_Debugging"],
Cell[23627, 698, 452, 8, 70, "Text",
  CellTags->"SD_Debugging"],
Cell[24082, 708, 410, 7, 70, "Text",
  CellTags->"SD_Debugging"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24541, 721, 65, 1, 70, "Section",
  CellTags->"SD_Console"],

Cell[CellGroupData[{
Cell[24631, 726, 59, 1, 70, "Subsection",
  CellTags->"SD_Intro1"],
Cell[24693, 729, 936, 14, 70, "Text",
  CellTags->"SD_Intro1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25666, 748, 69, 1, 70, "Subsection",
  CellTags->"SD_Debug_button"],
Cell[25738, 751, 844, 13, 70, "Text",
  CellTags->"SD_Debug_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26619, 769, 67, 1, 70, "Subsection",
  CellTags->"SD_Step_button"],
Cell[26689, 772, 506, 8, 70, "Text",
  CellTags->"SD_Step_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27232, 785, 71, 1, 70, "Subsection",
  CellTags->"SD_Resume_button"],
Cell[27306, 788, 505, 8, 70, "Text",
  CellTags->"SD_Resume_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27848, 801, 71, 1, 70, "Subsection",
  CellTags->"SD_Step_N_button"],
Cell[27922, 804, 321, 6, 70, "Text",
  CellTags->"SD_Step_N_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28280, 815, 69, 1, 70, "Subsection",
  CellTags->"SD_Run_N_button"],
Cell[28352, 818, 234, 5, 70, "Text",
  CellTags->"SD_Run_N_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28623, 828, 77, 1, 70, "Subsection",
  CellTags->"SD_Goto_step_button"],
Cell[28703, 831, 605, 10, 70, "Text",
  CellTags->"SD_Goto_step_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29345, 846, 77, 1, 70, "Subsection",
  CellTags->"SD_Step_over_button"],
Cell[29425, 849, 415, 7, 70, "Text",
  CellTags->"SD_Step_over_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29877, 861, 69, 1, 70, "Subsection",
  CellTags->"SD_Trace_button"],
Cell[29949, 864, 184, 4, 70, "Text",
  CellTags->"SD_Trace_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30170, 873, 73, 1, 70, "Subsection",
  CellTags->"SD_Options_button"],
Cell[30246, 876, 313, 6, 70, "Text",
  CellTags->"SD_Options_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30596, 887, 69, 1, 70, "Subsection",
  CellTags->"SD_Watch_button"],
Cell[30668, 890, 393, 7, 70, "Text",
  CellTags->"SD_Watch_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31098, 902, 75, 1, 70, "Subsection",
  CellTags->"SD_Messages_button"],
Cell[31176, 905, 341, 6, 70, "Text",
  CellTags->"SD_Messages_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31554, 916, 81, 1, 70, "Subsection",
  CellTags->"SD_Breakpoints_button"],
Cell[31638, 919, 490, 8, 70, "Text",
  CellTags->"SD_Breakpoints_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32165, 932, 71, 1, 70, "Subsection",
  CellTags->"SD_Colour_button"],
Cell[32239, 935, 283, 5, 70, "Text",
  CellTags->"SD_Colour_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32559, 945, 77, 1, 70, "Subsection",
  CellTags->"SD_No_Colour_button"],
Cell[32639, 948, 171, 4, 70, "Text",
  CellTags->"SD_No_Colour_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32847, 957, 72, 1, 70, "Subsection",
  CellTags->"SD_Test_button"],
Cell[32922, 960, 642, 10, 70, "Text",
  CellTags->"SD_Test_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33601, 975, 77, 1, 70, "Subsection",
  CellTags->"SD_Interrupt_button"],
Cell[33681, 978, 597, 10, 70, "Text",
  CellTags->"SD_Interrupt_button"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34315, 993, 73, 1, 70, "Subsection",
  CellTags->"SD_Quit_button"],
Cell[34391, 996, 161, 4, 70, "Text",
  CellTags->"SD_Quit_button"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34601, 1006, 83, 1, 70, "Section",
  CellTags->"SD_Option_Inspector"],

Cell[CellGroupData[{
Cell[34709, 1011, 59, 1, 70, "Subsection",
  CellTags->"SD_Intro2"],
Cell[34771, 1014, 791, 12, 70, "Text",
  CellTags->"SD_Intro2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35599, 1031, 83, 1, 70, "Subsection",
  CellTags->"SD_Breakpoints_section"],
Cell[35685, 1034, 429, 7, 70, "Text",
  CellTags->"SD_Breakpoints_section"],
Cell[36117, 1043, 129, 3, 70, "Input",
  CellTags->"SD_Breakpoints_section"],
Cell[36249, 1048, 500, 8, 70, "Text",
  CellTags->"SD_Breakpoints_section"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36786, 1061, 77, 1, 70, "Subsection",
  CellTags->"SD_Messages_section"],
Cell[36866, 1064, 583, 9, 70, "Text",
  CellTags->"SD_Messages_section"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37486, 1078, 95, 1, 70, "Subsection",
  CellTags->"SD_Frequently_adjusted_options"],
Cell[37584, 1081, 252, 6, 70, "Text",
  CellTags->"SD_Frequently_adjusted_options"],
Cell[37839, 1089, 346, 7, 70, "Text",
  CellTags->"SD_Frequently_adjusted_options"],
Cell[38188, 1098, 526, 10, 70, "Text",
  CellTags->"SD_Frequently_adjusted_options"],
Cell[38717, 1110, 520, 9, 70, "Text",
  CellTags->"SD_Frequently_adjusted_options"],
Cell[39240, 1121, 328, 7, 70, "Text",
  CellTags->"SD_Frequently_adjusted_options"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39605, 1133, 87, 1, 70, "Subsection",
  CellTags->"Extra_syntax_checks"],
Cell[39695, 1136, 552, 9, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[40250, 1147, 150, 4, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[40403, 1153, 431, 10, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[40837, 1165, 209, 6, 70, "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{
Cell[41071, 1175, 153, 4, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[41227, 1181, 162, 4, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41426, 1190, 140, 4, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[41569, 1196, 149, 4, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],
Cell[41733, 1203, 400, 9, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[42136, 1214, 190, 5, 70, "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{
Cell[42351, 1223, 143, 4, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[42497, 1229, 144, 4, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42678, 1238, 206, 6, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[42887, 1246, 207, 6, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43131, 1257, 126, 3, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[43260, 1262, 127, 3, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43424, 1270, 199, 6, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[43626, 1278, 200, 6, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],
Cell[43841, 1287, 216, 5, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[44060, 1294, 396, 8, 70, "Text",
  CellTags->"Extra_syntax_checks"],
Cell[44459, 1304, 407, 11, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[44869, 1317, 258, 6, 70, "Text",
  CellTags->"Extra_syntax_checks"],

Cell[CellGroupData[{
Cell[45152, 1327, 244, 7, 70, "Input",
  CellTags->"Extra_syntax_checks"],
Cell[45399, 1336, 453, 14, 70, "Output",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],
Cell[45867, 1353, 124, 3, 70, "Text",
  CellTags->"Extra_syntax_checks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46028, 1361, 113, 1, 70, "Subsection",
  CellTags->"SD_Miscellaneous_debugger_configuration"],
Cell[46144, 1364, 370, 7, 70, "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],
Cell[46517, 1373, 416, 10, 70, "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],
Cell[46936, 1385, 394, 8, 70, "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],
Cell[47333, 1395, 366, 7, 70, "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"],
Cell[47702, 1404, 415, 9, 70, "Text",
  CellTags->"SD_Miscellaneous_debugger_configuration"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48166, 1419, 82, 1, 70, "Section",
  CellTags->"SD_Debugging_using_colour"],
Cell[48251, 1422, 931, 15, 70, "Text",
  CellTags->"SD_Debugging_using_colour"],

Cell[CellGroupData[{
Cell[49207, 1441, 994, 24, 70, "Input",
  CellTags->"SD_Debugging_using_colour"],
Cell[50204, 1467, 1211, 39, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[51418, 1508, 476, 16, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[51897, 1526, 476, 16, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[52376, 1544, 476, 16, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[52855, 1562, 477, 16, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[53335, 1580, 288, 9, 70, "Print",
  CellTags->"SD_Debugging_using_colour"],
Cell[53626, 1591, 70, 1, 70, "Output",
  CellTags->"SD_Debugging_using_colour"]
}, Open  ]],
Cell[53711, 1595, 541, 10, 70, "Text",
  CellTags->"SD_Debugging_using_colour"],
Cell[54255, 1607, 189, 4, 70, "Text",
  CellTags->"SD_Debugging_using_colour"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54481, 1616, 87, 1, 70, "Section",
  CellTags->"SD_ContextDependantHelp"],

Cell[CellGroupData[{
Cell[54593, 1621, 59, 1, 70, "Subsection",
  CellTags->"SD_Intro3"],
Cell[54655, 1624, 165, 4, 70, "Text",
  CellTags->"SD_Intro3"],

Cell[CellGroupData[{
Cell[54845, 1632, 69, 1, 70, "Subsubsection",
  CellTags->"SD_StandbyState"],
Cell[54917, 1635, 618, 10, 70, "Text",
  CellTags->"SD_StandbyState"],
Cell[55538, 1647, 419, 8, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55994, 1660, 69, 1, 70, "Subsubsection",
  CellTags->"SD_PausingState"],
Cell[56066, 1663, 272, 5, 70, "Text",
  CellTags->"SD_PausingState"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56375, 1673, 69, 1, 70, "Subsubsection",
  CellTags->"SD_RunningState"],
Cell[56447, 1676, 462, 8, 70, "Text",
  CellTags->"SD_RunningState"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[56970, 1691, 96, 1, 70, "Section",
  CellTags->"SD_TraceScan_limitations"],
Cell[57069, 1694, 374, 8, 70, "Text",
  CellTags->"SD_TraceScan_limitations"],
Cell[57446, 1704, 719, 11, 70, "Text",
  CellTags->"SD_TraceScan_limitations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58202, 1720, 68, 1, 70, "Section",
  CellTags->"SD_For_the_curious"],
Cell[58273, 1723, 2104, 35, 70, "Text",
  CellTags->"SD_For_the_curious"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

