(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11192,        355]*)
(*NotebookOutlinePosition[     43614,       1394]*)
(*  CellTagsIndexPosition[     43394,       1384]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\(M - Debug\ Option\ inspector\),
      FontSize->36,
      FontWeight->"Bold"]], "Text",
  CellMargins->{{0, 0}, {0, 0}},
  TextAlignment->Center,
  Background->RGBColor[0.0234379, 0.64062, 0.285161]],

Cell[CellGroupData[{

Cell["Breakpoints", "Subsection",
  CellTags->"Breakpoints_section"],

Cell["\<\
The following cell contains a list of the currently active breakpoints. You \
can alter this list to add/remove entries and then press the 'submit' button \
to change the breakpoint settings. Each element of this list should be a \
pattern at which you wish the debugger to pause. Note that the coloured \
expression breakpoints are not part of this list.\
\>", "Text",
  CellTags->"Breakpoints_section"],

Cell[CellGroupData[{

Cell[BoxData[
    \({}\)], "Input",
  CellTags->{"Breakpoints", "Breakpoints_section"}],

Cell[BoxData[
    TagBox[
      ButtonBox["Submit",
        ButtonFunction:>MDebug`Private`Update\[Breve]Breakpoints[ ],
        ButtonEvaluator->Automatic,
        Active->True],
      DisplayForm]], "Output",
  CellLabel->"Out[3]//DisplayForm=",
  CellTags->"Breakpoints_section"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Messages", "Subsection",
  CellTags->"Messages_section"],

Cell["\<\
By default the debugger treats all diagnostics (that are not suppressed by \
the Off operation) as fatal. The following cell contains a list of messages \
that you wish to appear without causing the program to stop. You can alter \
this list to add/remove entries and then press the 'submit' button to change \
the breakpoint settings. Each element of this list should be a message such \
as myfunc::diagnostic. Note that this facility is particularly useful for \
debugging code which defines and uses messages of its own.\
\>", "Text",
  CellTags->"Messages_section"],

Cell[CellGroupData[{

Cell[BoxData[
    \({}\)], "Input",
  CellTags->{"Messages", "Messages_section"}],

Cell[BoxData[
    ButtonBox["Submit",
      ButtonFunction:>MDebug`Private`Update\[Breve]Messages[ ],
      ButtonEvaluator->Automatic,
      Active->True]], "Output",
  CellLabel->"Out[3]//DisplayForm=",
  CellTags->"Messages_section"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequently adjusted options", "Subsection",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Colour\[Breve]Break],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Break\ on\ coloured\ expressions\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Dbg\[Breve]Suppress\[Breve]Packages],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Conceal\ package\ operations\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Extra\[Breve]Syntax\[Breve]Checks],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Apply\ extra\ syntax\ checks\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Use\[Breve]Recorder],
              ButtonEvaluator->Automatic,
              Active->True],
            
            FontWeight->
              "Bold"], \(Record\ debug\ steps\ \((for\ step\ information\ \
button)\)\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(Multi - \(\(step\)\(\ \)\(count\)\(\ \)\)\), Cell[BoxData[
                FrameBox["10"]], "Input"], 
            StyleBox[
              ButtonBox["Submit",
                
                ButtonFunction:>
                  MDebug`Private`Adjust\[Breve]Step\[Breve]Number[ ],
                ButtonEvaluator->Automatic,
                Active->True],
              Background->GrayLevel[0.8]]}
          }],
      DisplayForm]], "Text",
  CellTags->"Options_section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Details of extra syntax checks", "Subsection",
  CellTags->"Options_section"],

Cell["\<\
Note that these options only work if the \"Apply extra syntax checks\" option \
is selected.\
\>", "Text"],

Cell[BoxData[
    RowBox[{GridBox[{
          {
            StyleBox[
              ButtonBox["\[Checkmark]",
                
                ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                  MDebug`Private`Check\[Breve]Argument\[Breve]Consistency],
                ButtonEvaluator->Automatic,
                Active->True],
              FontWeight->"Bold"], \(Check\ argument\ counts\)}
          }], " ", "and", " ", "validity"}]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[
    RowBox[{GridBox[{
          {
            StyleBox[
              ButtonBox["\[Checkmark]",
                
                ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                  MDebug`Private`Fault\[Breve]Implicit\[Breve]Nulls],
                ButtonEvaluator->Automatic,
                Active->True],
              FontWeight->"Bold"], \(Fault\ implicit\ nulls\)}
          }], " "}]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Fault\[Breve]Nonstandard\[Breve]Heads],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Fault\ non - standard\ heads\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Fault\[Breve]Suspicious\[Breve]Multiplies],
              ButtonEvaluator->Automatic,
              Active->True],
            
            FontWeight->
              "Bold"], \(Fault\ suspicious\ implicit\ multiplications\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Fault\[Breve]Unbound\[Breve]Slots],
              ButtonEvaluator->Automatic,
              Active->True],
            
            FontWeight->
              "Bold"], \(Fault\ use\ of\ slot\ notation\ \((#)\)\ outside\ of\
\ pure\ functions\)}
        }]], "Text",
  CellTags->"Options_section"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous debugger configuration", "Subsection",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Floating\[Breve]Console],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Debugger\ console\ floating\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox[" ",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Trace\[Breve]Internal],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Use\ TraceInternal\ for\ debug\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox[" ",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Use\[Breve]Multiple\[Breve]Info\[Breve]\
Notebooks],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Use\ multiple\ information\ notebooks\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Use\[Breve]Message\[Breve]Boxes],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Use\ Message\ boxes\)}
        }]], "Text",
  CellTags->"Options_section"],

Cell[BoxData[GridBox[{
        {
          StyleBox[
            ButtonBox["\[Checkmark]",
              
              ButtonFunction:>MDebug`Private`DbgToggleButton[ 
                MDebug`Private`Use\[Breve]Random\[Breve]Seed],
              ButtonEvaluator->Automatic,
              Active->True],
            FontWeight->"Bold"], \(Re - seed\ random\ number\ generator\)}
        }]], "Text",
  CellTags->"Options_section"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
WindowSize->{990, 895},
WindowMargins->{{Automatic, 86}, {14, Automatic}},
Background->GrayLevel[0.752941],
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    CellFrameLabelMargins->6,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    ShowCellLabel->False],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text",
    ShowCellLabel->False],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellLabel->False,
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{18, 10}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 4}, {0, 0}},
    CellFrameMargins->4,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 10}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->5,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellMargins->{{18, 4}, {10, 30}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{18, 4}, {10, 30}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->None,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{18, 50}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 50}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 55}, {5, 4}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    FontSize->8]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->16,
    FontWeight->"Bold",
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->14,
    FontWeight->"Bold",
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Open  ]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {10, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontSize->16,
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 0}},
    ShowCellLabel->False,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->1,
    CellMargins->{{55, 10}, {0, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->16,
    FontWeight->"Bold",
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Oblique"],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, 26}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->16,
    Background->GrayLevel[0.700008]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->RGBColor[0.500008, 0.996109, 0.996109]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{18, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->False,
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {2, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}], FontFamily -> 
            "Helvetica", FontSize -> 10, FontWeight -> "Bold"]}, {
        None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}], FontFamily -> 
            "Helvetica", FontSize -> 8, FontWeight -> "Bold"]}, {
        None, None}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
            FontSize -> 10, FontWeight -> "Bold"], None}},
    TextAlignment->Left,
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
            FontSize -> 10, FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Breakpoints_section"->{
    Cell[2007, 61, 68, 1, 54, "Subsection",
      CellTags->"Breakpoints_section"],
    Cell[2078, 64, 414, 7, 68, "Text",
      CellTags->"Breakpoints_section"],
    Cell[2517, 75, 87, 2, 47, "Input",
      CellTags->{"Breakpoints", "Breakpoints_section"}],
    Cell[2607, 79, 282, 8, 51, "Output",
      CellTags->"Breakpoints_section"]},
  "Breakpoints"->{
    Cell[2517, 75, 87, 2, 47, "Input",
      CellTags->{"Breakpoints", "Breakpoints_section"}]},
  "Messages_section"->{
    Cell[2938, 93, 62, 1, 54, "Subsection",
      CellTags->"Messages_section"],
    Cell[3003, 96, 579, 9, 88, "Text",
      CellTags->"Messages_section"],
    Cell[3607, 109, 81, 2, 47, "Input",
      CellTags->{"Messages", "Messages_section"}],
    Cell[3691, 113, 236, 6, 51, "Output",
      CellTags->"Messages_section"]},
  "Messages"->{
    Cell[3607, 109, 81, 2, 47, "Input",
      CellTags->{"Messages", "Messages_section"}]},
  "Options_section"->{
    Cell[3976, 125, 80, 1, 54, "Subsection",
      CellTags->"Options_section"],
    Cell[4059, 128, 415, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[4477, 141, 427, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[4907, 154, 425, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[5335, 167, 471, 14, 31, "Text",
      CellTags->"Options_section"],
    Cell[5809, 183, 518, 14, 33, "Text",
      CellTags->"Options_section"],
    Cell[6364, 202, 83, 1, 54, "Subsection",
      CellTags->"Options_section"],
    Cell[6569, 210, 491, 12, 31, "Text",
      CellTags->"Options_section"],
    Cell[7063, 224, 460, 12, 31, "Text",
      CellTags->"Options_section"],
    Cell[7526, 238, 429, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[7958, 251, 477, 13, 31, "Text",
      CellTags->"Options_section"],
    Cell[8438, 266, 496, 14, 31, "Text",
      CellTags->"Options_section"],
    Cell[8971, 285, 89, 1, 54, "Subsection",
      CellTags->"Options_section"],
    Cell[9063, 288, 414, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[9480, 301, 404, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[9887, 314, 440, 12, 31, "Text",
      CellTags->"Options_section"],
    Cell[10330, 328, 414, 11, 31, "Text",
      CellTags->"Options_section"],
    Cell[10747, 341, 429, 11, 31, "Text",
      CellTags->"Options_section"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Breakpoints_section", 41028, 1319},
  {"Breakpoints", 41388, 1328},
  {"Messages_section", 41509, 1331},
  {"Messages", 41853, 1340},
  {"Options_section", 41968, 1343}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 228, 6, 59, "Text"],

Cell[CellGroupData[{
Cell[2007, 61, 68, 1, 54, "Subsection",
  CellTags->"Breakpoints_section"],
Cell[2078, 64, 414, 7, 68, "Text",
  CellTags->"Breakpoints_section"],

Cell[CellGroupData[{
Cell[2517, 75, 87, 2, 47, "Input",
  CellTags->{"Breakpoints", "Breakpoints_section"}],
Cell[2607, 79, 282, 8, 51, "Output",
  CellTags->"Breakpoints_section"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2938, 93, 62, 1, 54, "Subsection",
  CellTags->"Messages_section"],
Cell[3003, 96, 579, 9, 88, "Text",
  CellTags->"Messages_section"],

Cell[CellGroupData[{
Cell[3607, 109, 81, 2, 47, "Input",
  CellTags->{"Messages", "Messages_section"}],
Cell[3691, 113, 236, 6, 51, "Output",
  CellTags->"Messages_section"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3976, 125, 80, 1, 54, "Subsection",
  CellTags->"Options_section"],
Cell[4059, 128, 415, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[4477, 141, 427, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[4907, 154, 425, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[5335, 167, 471, 14, 31, "Text",
  CellTags->"Options_section"],
Cell[5809, 183, 518, 14, 33, "Text",
  CellTags->"Options_section"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6364, 202, 83, 1, 54, "Subsection",
  CellTags->"Options_section"],
Cell[6450, 205, 116, 3, 28, "Text"],
Cell[6569, 210, 491, 12, 31, "Text",
  CellTags->"Options_section"],
Cell[7063, 224, 460, 12, 31, "Text",
  CellTags->"Options_section"],
Cell[7526, 238, 429, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[7958, 251, 477, 13, 31, "Text",
  CellTags->"Options_section"],
Cell[8438, 266, 496, 14, 31, "Text",
  CellTags->"Options_section"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8971, 285, 89, 1, 54, "Subsection",
  CellTags->"Options_section"],
Cell[9063, 288, 414, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[9480, 301, 404, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[9887, 314, 440, 12, 31, "Text",
  CellTags->"Options_section"],
Cell[10330, 328, 414, 11, 31, "Text",
  CellTags->"Options_section"],
Cell[10747, 341, 429, 11, 31, "Text",
  CellTags->"Options_section"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

